@@ -1,20 +1,13 @@
 import re
-from typing import TYPE_CHECKING, List, Optional
+from typing import TYPE_CHECKING
 
 from starlite.exceptions import ImproperlyConfiguredException
 from starlite.openapi.constants import PYDANTIC_FIELD_SHAPE_MAP
 
 if TYPE_CHECKING:
-    from typing import Union
-
     from pydantic.fields import ModelField
 
-    from starlite.app import Starlite
-    from starlite.controller import Controller
-    from starlite.handlers.http import HTTPRouteHandler
     from starlite.openapi.enums import OpenAPIType
-    from starlite.router import Router
-
 
 CAPITAL_LETTERS_PATTERN = re.compile(r"(?=[A-Z])")
 
@@ -24,20 +17,6 @@ def pascal_case_to_text(string: str) -> str:
     return " ".join(re.split(CAPITAL_LETTERS_PATTERN, string)).strip()
 
 
-def extract_tags_from_route_handler(route_handler: "HTTPRouteHandler") -> Optional[List[str]]:
-    """Extracts and combines tags from route_handler and any owners."""
-    child_tags = route_handler.tags or []
-    parent_tags: List[str] = []
-    obj: "Union[HTTPRouteHandler, Controller, Router, Starlite]"
-    obj = route_handler
-    while hasattr(obj, "owner"):
-        if obj.owner is None:
-            break
-        obj = obj.owner
-        parent_tags += getattr(obj, "tags", None) or []
-    return list(set(child_tags) | set(parent_tags)) or None
-
-
 def get_openapi_type_for_complex_type(field: "ModelField") -> "OpenAPIType":
     """We are dealing with complex types in this case.
 
