@@ -39,44 +39,44 @@ def Parameter(
     both parameter parsing and OpenAPI schema generation.
 
     Args:
-        value_type (Any, optional): `Undefined` by default.
-        header (str | None, optional): The header parameter key - required for header parameters.
-        cookie (str | None, optional): The cookie parameter key - required for cookie parameters.
-        query (str | None, optional): The query parameter key for this parameter.
-        examples (list[Example] | None, optional): A list of Example models.
-        external_docs (ExternalDocumentation | None, optional): A url pointing at external documentation for the given
+        value_type: `Undefined` by default.
+        header: The header parameter key - required for header parameters.
+        cookie: The cookie parameter key - required for cookie parameters.
+        query: The query parameter key for this parameter.
+        examples: A list of Example models.
+        external_docs: A url pointing at external documentation for the given
             parameter.
-        content_encoding (str | None, optional): The content encoding of the value. Applicable on to string values. See
+        content_encoding: The content encoding of the value. Applicable on to string values. See
             OpenAPI 3.1 for details.
-        required (bool, optional): A boolean flag dictating whether this parameter is required. If set to False, None
+        required: A boolean flag dictating whether this parameter is required. If set to False, None
             values will be allowed. Defaults to True.
-        default (Any, optional): A default value. If const is true, this value is required.
-        title (str | None, optional): String value used in the title section of the OpenAPI schema for the given
+        default: A default value. If const is true, this value is required.
+        title: String value used in the title section of the OpenAPI schema for the given
             parameter.
-        description (str | None, optional): String value used in the description section of the OpenAPI schema for the
+        description: String value used in the description section of the OpenAPI schema for the
             given parameter.
-        const (bool, optional): A boolean flag dictating whether this parameter is a constant. If True, the value passed
+        const: A boolean flag dictating whether this parameter is a constant. If True, the value passed
             to the parameter must equal its default value. This also causes the OpenAPI const field to be populated with
             the default value.
-        gt (float | None, optional): Constrict value to be greater than a given float or int. Equivalent to
+        gt: Constrict value to be greater than a given float or int. Equivalent to
             exclusiveMinimum in the OpenAPI specification.
-        ge (float | None, optional): Constrict value to be greater or equal to a given float or int. Equivalent to
+        ge: Constrict value to be greater or equal to a given float or int. Equivalent to
             minimum in the OpenAPI specification.
-        lt (float | None, optional): Constrict value to be less than a given float or int. Equivalent to
+        lt: Constrict value to be less than a given float or int. Equivalent to
             exclusiveMaximum in the OpenAPI specification.
-        le (float | None, optional): Constrict value to be less or equal to a given float or int. Equivalent to maximum
+        le: Constrict value to be less or equal to a given float or int. Equivalent to maximum
             in the OpenAPI specification.
-        multiple_of (float | None, optional): Constrict value to a multiple of a given float or int. Equivalent to
+        multiple_of: Constrict value to a multiple of a given float or int. Equivalent to
             multipleOf in the OpenAPI specification.
-        min_items (int | None, optional): Constrict a set or a list to have a minimum number of items. Equivalent to
+        min_items: Constrict a set or a list to have a minimum number of items. Equivalent to
             minItems in the OpenAPI specification.
-        max_items (int | None, optional): Constrict a set or a list to have a maximum number of items. Equivalent to
+        max_items: Constrict a set or a list to have a maximum number of items. Equivalent to
             maxItems in the OpenAPI specification.
-        min_length (int | None, optional): Constrict a string or bytes value to have a minimum length. Equivalent to
+        min_length: Constrict a string or bytes value to have a minimum length. Equivalent to
             minLength in the OpenAPI specification.
-        max_length (int | None, optional): Constrict a string or bytes value to have a maximum length. Equivalent to
+        max_length: Constrict a string or bytes value to have a maximum length. Equivalent to
             maxLength in the OpenAPI specification.
-        regex (str | None, optional): A string representing a regex against which the given string will be matched.
+        regex: A string representing a regex against which the given string will be matched.
             Equivalent to pattern in the OpenAPI specification.
     """
     extra: Dict[str, Any] = dict(is_parameter=True)
@@ -133,39 +133,39 @@ def Body(
     both parameter parsing and OpenAPI schema generation.
 
     Args:
-        media_type (str | RequestEncodingType): Defaults to RequestEncodingType.JSON.
-        examples (list[Example] | None, optional): A list of Example models.
-        external_docs (ExternalDocumentation | None, optional): A url pointing at external documentation for the given
+        media_type: Defaults to RequestEncodingType.JSON.
+        examples: A list of Example models.
+        external_docs: A url pointing at external documentation for the given
             parameter.
-        content_encoding (str | None, optional): The content encoding of the value. Applicable on to string values. See
+        content_encoding: The content encoding of the value. Applicable on to string values. See
             OpenAPI 3.1 for details.
-        default (Any, optional): A default value. If const is true, this value is required.
-        title (str | None, optional): String value used in the title section of the OpenAPI schema for the given
+        default: A default value. If const is true, this value is required.
+        title: String value used in the title section of the OpenAPI schema for the given
             parameter.
-        description (str | None, optional): String value used in the description section of the OpenAPI schema for the
+        description: String value used in the description section of the OpenAPI schema for the
             given parameter.
-        const (bool, optional): A boolean flag dictating whether this parameter is a constant. If True, the value passed
+        const: A boolean flag dictating whether this parameter is a constant. If True, the value passed
             to the parameter must equal its default value. This also causes the OpenAPI const field to be populated with
             the default value.
-        gt (float | None, optional): Constrict value to be greater than a given float or int. Equivalent to
+        gt: Constrict value to be greater than a given float or int. Equivalent to
             exclusiveMinimum in the OpenAPI specification.
-        ge (float | None, optional): Constrict value to be greater or equal to a given float or int. Equivalent to
+        ge: Constrict value to be greater or equal to a given float or int. Equivalent to
             minimum in the OpenAPI specification.
-        lt (float | None, optional): Constrict value to be less than a given float or int. Equivalent to
+        lt: Constrict value to be less than a given float or int. Equivalent to
             exclusiveMaximum in the OpenAPI specification.
-        le (float | None, optional): Constrict value to be less or equal to a given float or int. Equivalent to maximum
+        le: Constrict value to be less or equal to a given float or int. Equivalent to maximum
             in the OpenAPI specification.
-        multiple_of (float | None, optional): Constrict value to a multiple of a given float or int. Equivalent to
+        multiple_of: Constrict value to a multiple of a given float or int. Equivalent to
             multipleOf in the OpenAPI specification.
-        min_items (int | None, optional): Constrict a set or a list to have a minimum number of items. Equivalent to
+        min_items: Constrict a set or a list to have a minimum number of items. Equivalent to
             minItems in the OpenAPI specification.
-        max_items (int | None, optional): Constrict a set or a list to have a maximum number of items. Equivalent to
+        max_items: Constrict a set or a list to have a maximum number of items. Equivalent to
             maxItems in the OpenAPI specification.
-        min_length (int | None, optional): Constrict a string or bytes value to have a minimum length. Equivalent to
+        min_length: Constrict a string or bytes value to have a minimum length. Equivalent to
             minLength in the OpenAPI specification.
-        max_length (int | None, optional): Constrict a string or bytes value to have a maximum length. Equivalent to
+        max_length: Constrict a string or bytes value to have a maximum length. Equivalent to
             maxLength in the OpenAPI specification.
-        regex (str | None, optional): A string representing a regex against which the given string will be matched.
+        regex: A string representing a regex against which the given string will be matched.
             Equivalent to pattern in the OpenAPI specification.
     """
     extra: Dict[str, Any] = {}
@@ -198,8 +198,8 @@ def Dependency(*, default: Any = Undefined, skip_validation: bool = False) -> An
     both parameter parsing and OpenAPI schema generation.
 
     Args:
-        default (Any, optional): default value if dependency not provided.
-        skip_validation (bool, optional): If `True` provided dependency values are not validated by signature model.
+        default: default value if dependency not provided.
+        skip_validation: If `True` provided dependency values are not validated by signature model.
     """
     extra: Dict[str, Any] = {EXTRA_KEY_IS_DEPENDENCY: True, EXTRA_KEY_SKIP_VALIDATION: skip_validation}
     return Field(default, **extra)  # type: ignore[pydantic-field]
