@@ -1,3 +1,3 @@
 from .base import TemplateEngineProtocol, TemplateProtocol
 
-__all__ = ["TemplateEngineProtocol", "TemplateProtocol"]
+__all__ = ("TemplateEngineProtocol", "TemplateProtocol")
